@@ -1,8 +1,8 @@
 /* main.c - core analysis suite
  *
  * Copyright (C) 1999, 2000, 2001, 2002 Mission Critical Linux, Inc.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 David Anderson
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 Red Hat, Inc. All rights reserved.
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 David Anderson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Red Hat, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,6 +59,7 @@ static struct option long_options[] = {
         {"reloc", required_argument, 0, 0},
 	{"active", 0, 0, 0},
 	{"minimal", 0, 0, 0},
+	{"mod", required_argument, 0, 0},
         {0, 0, 0, 0}
 };
 
@@ -74,7 +75,7 @@ main(int argc, char **argv)
 	 */
 	opterr = 0;
 	optind = 0;
-	while((c = getopt_long(argc, argv, "Lkgh::e:i:sSvc:d:tfp:m:",
+	while((c = getopt_long(argc, argv, "Lkgh::e:i:sSvc:d:tfp:m:x",
        		long_options, &option_index)) != -1) {
 		switch (c)
 		{
@@ -203,6 +204,9 @@ main(int argc, char **argv)
 		        else if (STREQ(long_options[option_index].name, "active"))
 				tt->flags |= ACTIVE_ONLY;
 
+		        else if (STREQ(long_options[option_index].name, "mod"))
+				kt->module_tree = optarg;
+
 		        else if (STREQ(long_options[option_index].name, "reloc")) {
 				if (!calculate(optarg, &kt->relocate, NULL, 0)) {
 					error(INFO, "invalid --reloc argument: %s\n",
@@ -317,6 +321,10 @@ main(int argc, char **argv)
 					optarg);
 			break;
 
+		case 'x':
+			pc->flags |= PRELOAD_EXTENSIONS;
+			break;
+
 		default:
 			error(INFO, "invalid option: %s\n",
 				argv[optind-1]);
@@ -401,6 +409,17 @@ main(int argc, char **argv)
                                 pc->readmem = read_kdump;
                                 pc->writemem = write_kdump;
 
+                        } else if (is_kvmdump(argv[optind])) {
+                                if (pc->flags & MEMORY_SOURCES) {
+                                        error(INFO,
+                                            "too many dumpfile arguments\n");
+                                        program_usage(SHORT_FORM);
+                                }
+                                pc->flags |= KVMDUMP;
+                                pc->dumpfile = argv[optind];
+                                pc->readmem = read_kvmdump;
+                                pc->writemem = write_kvmdump;
+
                         } else if (is_xendump(argv[optind])) {
                                 if (pc->flags & MEMORY_SOURCES) {
                                         error(INFO,
@@ -412,6 +431,10 @@ main(int argc, char **argv)
                                 pc->readmem = read_xendump;
                                 pc->writemem = write_xendump;
 
+                        } else if (is_system_map(argv[optind])) {
+                                pc->system_map = argv[optind];
+                                pc->flags |= (SYSMAP|SYSMAP_ARG);
+
 			} else if (is_diskdump(argv[optind])) {
                                 if ((pc->flags & MEMORY_SOURCES) &&
                                     (!dumpfile_is_split())) {
@@ -435,10 +458,6 @@ main(int argc, char **argv)
 				pc->readmem = read_lkcd_dumpfile;
 				pc->writemem = write_lkcd_dumpfile;
 
-                        } else if (is_system_map(argv[optind])) {
-                                pc->system_map = argv[optind];
-                                pc->flags |= (SYSMAP|SYSMAP_ARG);
-
 			} else if (is_mclx_compressed_dump(argv[optind])) {
 				if (pc->flags & MEMORY_SOURCES) {
 					error(INFO,
@@ -563,6 +582,9 @@ main_loop(void)
 
         pc->flags |= RUNTIME;
 
+	if (pc->flags & PRELOAD_EXTENSIONS)
+		preload_extensions();
+
 	/*
 	 *  Return here if a non-recoverable error occurs
 	 *  during command execution.
@@ -762,7 +784,8 @@ is_external_command(void)
 			else
                         	strcat(command, args[i]);
                 }
-                system(command);
+                if (system(command) == -1)
+			perror(command);
                 return TRUE;
         }
 
@@ -960,8 +983,8 @@ dump_program_context(void)
                 sprintf(&buf[strlen(buf)], "%sIN_FOREACH", others++ ? "|" : "");
         if (pc->flags & MFD_RDWR)
                 sprintf(&buf[strlen(buf)], "%sMFD_RDWR", others++ ? "|" : "");
-        if (pc->flags & DFD_RDWR)
-                sprintf(&buf[strlen(buf)], "%sDFD_RDWR", others++ ? "|" : "");
+        if (pc->flags & KVMDUMP)
+                sprintf(&buf[strlen(buf)], "%sKVMDUMP", others++ ? "|" : "");
         if (pc->flags & SILENT)
                 sprintf(&buf[strlen(buf)], "%sSILENT", others++ ? "|" : "");
         if (pc->flags & HASH)
@@ -1113,6 +1136,9 @@ dump_program_context(void)
         if (pc->flags & CRASHBUILTIN)
                 sprintf(&buf[strlen(buf)], 
 			"%sCRASHBUILTIN", others++ ? "|" : "");
+        if (pc->flags & PRELOAD_EXTENSIONS)
+                sprintf(&buf[strlen(buf)], 
+			"%sPRELOAD_EXTENSIONS", others++ ? "|" : "");
 
 	if (pc->flags)
 		strcat(buf, ")");
@@ -1309,6 +1335,8 @@ dump_program_context(void)
 		fprintf(fp, "%sUD2A_INSTRUCTION", others ? "|" : "");
         if (pc->curcmd_flags & IRQ_IN_USE)
 		fprintf(fp, "%sIRQ_IN_USE", others ? "|" : "");
+        if (pc->curcmd_flags & MODULE_TREE)
+		fprintf(fp, "%sMODULE_TREE", others ? "|" : "");
 	fprintf(fp, ")\n");
 	fprintf(fp, "   curcmd_private: %llx\n", pc->curcmd_private); 
 	fprintf(fp, "       sigint_cnt: %d\n", pc->sigint_cnt);
